@@ -25,9 +25,14 @@ import (
 
 	"github.com/goplus/gop/ast"
 	"github.com/goplus/gop/format"
+	"github.com/goplus/gop/printer"
 	"github.com/goplus/gop/token"
 )
 
+func init() {
+	printer.SetDebug(printer.DbgFlagAll)
+}
+
 func TestNoPkgDecl(t *testing.T) {
 	var dst bytes.Buffer
 	fset := token.NewFileSet()
@@ -51,7 +56,9 @@ func TestFuncs(t *testing.T) {
 			&ast.FuncDecl{
 				Type: &ast.FuncType{Params: &ast.FieldList{}},
 				Name: &ast.Ident{Name: "foo"},
-				Body: &ast.BlockStmt{},
+				Body: &ast.BlockStmt{
+					List: []ast.Stmt{&printer.NewlineStmt{}},
+				},
 			},
 			&ast.FuncDecl{
 				Type: &ast.FuncType{Params: &ast.FieldList{}},
@@ -64,6 +71,7 @@ func TestFuncs(t *testing.T) {
 		t.Fatal("format.Node failed:", err)
 	}
 	if dst.String() != `func foo() {
+
 }
 
 func bar() {
@@ -136,7 +144,11 @@ func TestFromParse(t *testing.T) {
 		if err != nil {
 			return err
 		}
-		if !info.IsDir() && filepath.Ext(path) == ".gop" {
+		name := info.Name()
+		if name == "cmd.gop" { // skip this file
+			return nil
+		}
+		if !info.IsDir() && filepath.Ext(name) == ".gop" {
 			t.Log(path)
 			testFrom(t, path)
 		}
